@@ -29,6 +29,7 @@ module Filesystem.Path.CurrentOS
 	-- * Rule&#x2010;specific path properties
 	, valid
 	, splitSearchPath
+	, splitSearchPathString
 	) where
 
 import           Prelude hiding (FilePath)
@@ -41,14 +42,18 @@ import           Filesystem.Path
 import qualified Filesystem.Path as F
 import qualified Filesystem.Path.Rules as R
 
-#if defined(CABAL_OS_WINDOWS) || defined(CABAL_OS_DARWIN)
-#define PLATFORM_PATH_FORMAT T.Text
+#if defined(__HADDOCK__)
+#  define PLATFORM_PATH_FORMAT platformTextFormat
+#elif defined(CABAL_OS_WINDOWS) || defined(CABAL_OS_DARWIN)
+#  define PLATFORM_PATH_FORMAT T.Text
 #else
-#define PLATFORM_PATH_FORMAT B.ByteString
+#  define PLATFORM_PATH_FORMAT B.ByteString
 #endif
 
 currentOS :: R.Rules PLATFORM_PATH_FORMAT
-#if defined(CABAL_OS_WINDOWS)
+#if defined(__HADDOCK__)
+currentOS = undefined
+#elif defined(CABAL_OS_WINDOWS)
 currentOS = R.windows
 #elif defined(CABAL_OS_DARWIN)
 #if __GLASGOW_HASKELL__ >= 702
@@ -114,6 +119,11 @@ valid = R.valid currentOS
 splitSearchPath :: PLATFORM_PATH_FORMAT -> [F.FilePath]
 splitSearchPath = R.splitSearchPath currentOS
 
+-- | splitSearchPathString is like 'splitSearchPath', but takes a string
+-- encoded in the format used by @System.IO@.
+splitSearchPathString :: String -> [F.FilePath]
+splitSearchPathString = R.splitSearchPathString currentOS
+
 -- | Convert a 'F.FilePath' to a platform&#x2010;specific format, suitable
 -- for use with external OS functions.
 --
